diff src/misc1.c @ 13772:cc21507ee4b1 v8.0.1758

patch 8.0.1758: open_line() returns TRUE/FALSE for success/failure commit https://github.com/vim/vim/commit/24a2d7264fc2394f69a9a890b34d1f09cf63b14e Author: Bram Moolenaar <Bram@vim.org> Date: Tue Apr 24 19:36:43 2018 +0200 patch 8.0.1758: open_line() returns TRUE/FALSE for success/failure Problem: open_line() returns TRUE/FALSE for success/failure. Solution: Return OK or FAIL.
author Christian Brabandt <cb@256bit.org>
date Tue, 24 Apr 2018 19:45:07 +0200
parents bcef80912112
children d0d8125ba692
line wrap: on
line diff
--- a/src/misc1.c
+++ b/src/misc1.c
@@ -588,7 +588,7 @@ cin_is_cinword(char_u *line)
  * "second_line_indent": indent for after ^^D in Insert mode or if flag
  *			  OPENLINE_COM_LIST
  *
  * Return TRUE for success, FALSE for failure
  */
     int
 open_line(
@@ -606,7 +606,7 @@ open_line(
     int		newindent = 0;		/* auto-indent of the new line */
     int		n;
     int		trunc_line = FALSE;	/* truncate current line afterwards */
-    int		retval = FALSE;		/* return value, default is FAIL */
+    int		retval = FAIL;		/* return value */
 #ifdef FEAT_COMMENTS
     int		extra_len = 0;		/* length of p_extra string */
     int		lead_len;		/* length of comment leader */
@@ -1642,7 +1642,7 @@ open_line(
     }
 #endif
 
-    retval = TRUE;		/* success! */
+    retval = OK;		/* success! */
 theend:
     curbuf->b_p_pi = saved_pi;
     vim_free(saved_line);
@@ -588,7 +588,7 @@ cin_is_cinword(char_u *line)
  *			  OPENLINE_COM_LIST
  *
- * Return TRUE for success, FALSE for failure
+ * Return OK for success, FAIL for failure
  */
     int